package com.example.kafka.service;

import com.example.kafka.entity.Order;
import com.example.kafka.entity.User;
import com.example.kafka.enumerator.OrderStatus;
import com.example.kafka.repository.OrderRepository;
import com.example.kafka.repository.UserRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;


/**
 * UserServiceImpl is implementation of UserService class
 */
@Service
public class UserServiceImpl implements UserService {

    @Autowired
    private UserRepository userRepository;

    @Autowired
    private OrderRepository orderRepository;


    /**
     * Create user into DB
     * @param user The user
     * @return The mono user
     */
    @Override
    public Mono<User> createUser(User user){
        return userRepository.save(user);
    }

    /**
     * Get all users
     * @return The flux user
     */
    @Override
    public Flux<User> getAllUsers(){
        return userRepository.findAll();
    }

    /**
     * Find user by id
     * @param userId The userId
     * @return The mono user
     */
    @Override
    public Mono<User> findById(String userId){
        return userRepository.findById(userId);
    }

    /**
     * Update the User details
     * @param userId The userId
     * @param user The user
     * @return The mono user
     */
    @Override
    public Mono<User> updateUser(String userId, User user){
        return userRepository.findById(userId).flatMap(dbUser -> {
                    dbUser.setAge(user.getAge());
                    dbUser.setBalance(user.getBalance());
                    return userRepository.save(dbUser);
                });
    }
}
